Utf16String

Struct Utf16String 

pub struct Utf16String { /* private fields */ }
An owned UTF-16 string consisting of UCS-2 code units.

Indexing this type is equivalent to indexing UTF-16 code units (not bytes), which are represented by u16.

Implementations

Source

impl Utf16String

pub fn new() -> Self

pub fn as_mut_utf16_str(&mut self) -> &mut Utf16Str

pub unsafe fn as_mut_vec(&mut self) -> &mut Vec<u16>

pub fn clear(&mut self)

pub fn insert(&mut self, index: usize, ch: char)

pub fn insert_utf16_str(&mut self, index: usize, string: &Utf16Str)

pub fn insert_utf8_str(&mut self, index: usize, string: &str)

pub fn push(&mut self, ch: char)

pub fn push_utf16_str(&mut self, string: &Utf16Str)

pub fn push_utf8_str(&mut self, string: &str)

pub fn remove(&mut self, index: usize) -> char

Removes a surrogate pair or a code unit from the specified index in code units, and returns the code point that was removed.

Panics

Panics if the index is out of bounds.

pub fn pop(&mut self) -> Option<char>

Removes the last surrogate pair or code unit, and returns the code point that was removed.

Methods from Deref<Target = Utf16Str>

pub fn len(&self) -> usize

Returns the number of UTF-16 code units representing the string.

pub fn as_ptr(&self) -> *const u16

pub fn as_mut_ptr(&mut self) -> *mut u16

pub fn code_units(&self) -> Iter<'_, u16>

Iterates the UTF-16 code units.

pub fn chars(&self) -> Utf16Chars<'_>

Iterates the code points in the string.

pub fn char_indices(&self) -> Utf16CharIndices<'_>

Iterates the indices and their code pointss in the string.

pub fn get<I: SliceIndex<Utf16Str>>( &self, index: I, ) -> Option<&<I as SliceIndex<Utf16Str>>::Output>

pub fn get_mut<I: SliceIndex<Utf16Str>>( &mut self, index: I, ) -> Option<&mut <I as SliceIndex<Utf16Str>>::Output>

pub unsafe fn get_unchecked<I: SliceIndex<Utf16Str>>( &self, index: I, ) -> &<I as SliceIndex<Utf16Str>>::Output

pub unsafe fn get_unchecked_mut<I: SliceIndex<Utf16Str>>( &mut self, index: I, ) -> &mut <I as SliceIndex<Utf16Str>>::Output

pub fn is_empty(&self) -> bool

pub fn to_owned(&self) -> Utf16String

pub fn to_utf8(&self) -> String

pub fn to_lowercase(&self) -> Utf16String

pub fn to_uppercase(&self) -> Utf16String